@@ -136,7 +136,7 @@ func listFields(t reflect.Type, parents []string, filter ListFieldFilter) []stri
 		return listFields(t.Elem(), append(parents, "<key>"), filter)
 	case reflect.Struct:
 		res := []string(nil)
-		for i := 0; i < t.NumField(); i++ {
+		for i := range t.NumField() {
 			field := t.Field(i)
 
 			if !isFieldPublic(field) {
@@ -145,7 +145,7 @@ func listFields(t reflect.Type, parents []string, filter ListFieldFilter) []stri
 
 			fieldParents := parents
 			if !field.Anonymous {
-				fieldParents = append(parents, field.Name)
+				fieldParents = append(parents, field.Name) //nolint:gocritic
 			}
 
 			res = append(res, listFields(field.Type, fieldParents, filter)...)
