@@ -2,7 +2,7 @@ package billing
 
 import (
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	billing "github.com/scaleway/scaleway-sdk-go/api/billing/v2beta1"
 )
