@@ -2,7 +2,7 @@ package block
 
 import (
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 )
