@@ -1,7 +1,7 @@
 package container
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	container "github.com/scaleway/scaleway-sdk-go/api/container/v1beta1"
 )
