@@ -5,7 +5,7 @@ import (
 	"testing"
 
 	"github.com/alecthomas/assert"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	container "github.com/scaleway/scaleway-cli/v2/internal/namespaces/container/v1beta1"
 	containerSDK "github.com/scaleway/scaleway-sdk-go/api/container/v1beta1"
 )
