@@ -1,6 +1,6 @@
 package edge_services
 
-import "github.com/scaleway/scaleway-cli/v2/internal/core"
+import "github.com/scaleway/scaleway-cli/v2/core"
 
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
