@@ -1,7 +1,7 @@
 package function
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	function "github.com/scaleway/scaleway-sdk-go/api/function/v1beta1"
 )
