@@ -1,6 +1,6 @@
 package iam_test
 
-import "github.com/scaleway/scaleway-cli/v2/internal/core"
+import "github.com/scaleway/scaleway-cli/v2/core"
 
 func addSSHKey(metaKey string, key string) core.BeforeFunc {
 	return func(ctx *core.BeforeFuncCtx) error {
