@@ -18,7 +18,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
 	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
-	"github.com/scaleway/scaleway-sdk-go/api/vpc/v1"
+	"github.com/scaleway/scaleway-sdk-go/api/vpc/v2"
 	"github.com/scaleway/scaleway-sdk-go/logger"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/scaleway/scaleway-sdk-go/validation"
@@ -366,9 +366,13 @@ func serverGetBuilder(c *core.Command) *core.Command {
 		nics := []customNICs{}
 
 		for _, nic := range getServerResp.Server.PrivateNics {
+			region, err := getServerResp.Server.Zone.Region()
+			if err != nil {
+				return nil, err
+			}
 			pn, err := vpcAPI.GetPrivateNetwork(&vpc.GetPrivateNetworkRequest{
 				PrivateNetworkID: nic.PrivateNetworkID,
-				Zone:             getServerResp.Server.Zone,
+				Region:           region,
 			})
 			if err != nil {
 				return nil, err
@@ -821,15 +825,20 @@ func serverDeleteCommand() *core.Command {
 				return nil, err
 			}
 
-			if deleteServerArgs.WithIP && server.Server.PublicIP != nil && !server.Server.PublicIP.Dynamic {
-				err = api.DeleteIP(&instance.DeleteIPRequest{
-					Zone: deleteServerArgs.Zone,
-					IP:   server.Server.PublicIP.ID,
-				})
-				if err != nil {
-					return nil, err
+			if deleteServerArgs.WithIP && server.Server.PublicIPs != nil {
+				for _, ip := range server.Server.PublicIPs {
+					if ip.Dynamic {
+						continue
+					}
+					err = api.DeleteIP(&instance.DeleteIPRequest{
+						Zone: deleteServerArgs.Zone,
+						IP:   ip.ID,
+					})
+					if err != nil {
+						return nil, err
+					}
+					_, _ = interactive.Printf("successfully deleted ip %s\n", ip.Address.String())
 				}
-				_, _ = interactive.Printf("successfully deleted ip %s\n", server.Server.PublicIP.Address.String())
 			}
 
 			deletedVolumeMessages := [][2]string(nil)
@@ -868,9 +877,13 @@ func serverDeleteCommand() *core.Command {
 				if err != nil {
 					logger.Debugf("cannot marshal human size %v", volume.Size)
 				}
+				volumeName := ""
+				if volume.Name != nil {
+					volumeName = *volume.Name
+				}
 				deletedVolumeMessages = append(deletedVolumeMessages, [2]string{
 					index,
-					fmt.Sprintf("successfully deleted volume %s (%s %s)", volume.Name, humanSize, volume.VolumeType),
+					fmt.Sprintf("successfully deleted volume %s (%s %s)", volumeName, humanSize, volume.VolumeType),
 				})
 			}
 
