@@ -19,7 +19,7 @@ func Test_ServerTerminate(t *testing.T) {
 
 	t.Run("without IP", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-jammy -w"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }}`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -40,7 +40,7 @@ func Test_ServerTerminate(t *testing.T) {
 
 	t.Run("with IP", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-jammy -w"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -61,7 +61,7 @@ func Test_ServerTerminate(t *testing.T) {
 
 	t.Run("without block", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-jammy additional-volumes.0=block:10G -w"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy additional-volumes.0=block:10G -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true with-block=false`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -76,7 +76,7 @@ func Test_ServerTerminate(t *testing.T) {
 
 	t.Run("with block", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-jammy additional-volumes.0=block:10G -w"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu-jammy additional-volumes.0=block:10G -w")),
 		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true with-block=true -w`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -103,7 +103,21 @@ func Test_ServerTerminate(t *testing.T) {
 func Test_ServerBackup(t *testing.T) {
 	t.Run("simple", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-jammy"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy")),
+		Cmd:        `scw instance server backup {{ .Server.ID }} name=backup`,
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			core.TestCheckExitCode(0),
+		),
+		AfterFunc: core.AfterFuncCombine(
+			core.ExecAfterCmd("scw instance image delete {{ .CmdResult.Image.ID }} with-snapshots=true"),
+			core.ExecAfterCmd("scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=local"),
+		),
+	}))
+
+	t.Run("With SBS volumes", core.Test(&core.TestConfig{
+		Commands:   instance.GetCommands(),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("root-volume=sbs:20G stopped=true image=ubuntu-jammy")),
 		Cmd:        `scw instance server backup {{ .Server.ID }} name=backup`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -119,7 +133,7 @@ func Test_ServerBackup(t *testing.T) {
 func Test_ServerAction(t *testing.T) {
 	t.Run("manual poweron", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu_jammy"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu_jammy")),
 		Cmd:        `scw instance server action {{ .Server.ID }} action=poweron --wait`,
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(0),
@@ -141,35 +155,3 @@ func Test_ServerAction(t *testing.T) {
 		),
 	}))
 }
-
-func Test_ServerEnableRoutedIP(t *testing.T) {
-	t.Run("simple", core.Test(&core.TestConfig{
-		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create zone=fr-par-3 type=PRO2-XXS image=ubuntu_jammy routed-ip-enabled=false ip=new --wait"),
-		Cmd:        `scw instance server enable-routed-ip zone=fr-par-3 {{ .Server.ID }} --wait`,
-		Check: core.TestCheckCombine(
-			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				t.Helper()
-				storedServer := ctx.Meta["Server"].(*instanceSDK.Server)
-				api := instanceSDK.NewAPI(ctx.Client)
-				server, err := api.GetServer(&instanceSDK.GetServerRequest{
-					Zone:     storedServer.Zone,
-					ServerID: storedServer.ID,
-				})
-				assert.Nil(t, err)
-				assert.Equal(t, scw.BoolPtr(true), server.Server.RoutedIPEnabled) //nolint: staticcheck // Field is deprecated but tested
-				ip, err := api.GetIP(&instanceSDK.GetIPRequest{
-					Zone: storedServer.Zone,
-					IP:   storedServer.PublicIP.ID,
-				})
-				assert.Nil(t, err)
-				assert.Equal(t, instanceSDK.IPTypeRoutedIPv4, ip.IP.Type)
-			},
-			core.TestCheckGolden(),
-			core.TestCheckExitCode(0),
-		),
-		AfterFunc: core.AfterFuncCombine(
-			core.ExecAfterCmd("scw instance server delete zone=fr-par-3 {{ .Server.ID }} force-shutdown=true with-ip=true with-volumes=local"),
-		),
-	}))
-}
