@@ -26,8 +26,10 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 20*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["0"].Size)
-				assert.Equal(t, 10*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].Size)
+				size0 := ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["0"].Size
+				size1 := ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].Size
+				assert.Equal(t, 20*scw.GB, instance.SizeValue(size0), "Size of volume should be 20 GB")
+				assert.Equal(t, 10*scw.GB, instance.SizeValue(size1), "Size of volume should be 10 GB")
 				assert.Equal(t, instanceSDK.VolumeServerVolumeTypeBSSD, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].VolumeType)
 			},
 			AfterFunc:       deleteServer("Server"),
@@ -44,8 +46,10 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 20*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["0"].Size)
-				assert.Equal(t, 10*scw.GB, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].Size)
+				size0 := ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["0"].Size
+				size1 := ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].Size
+				assert.Equal(t, 20*scw.GB, instance.SizeValue(size0), "Size of volume should be 20 GB")
+				assert.Equal(t, 10*scw.GB, instance.SizeValue(size1), "Size of volume should be 10 GB")
 				assert.Equal(t, instanceSDK.VolumeServerVolumeTypeLSSD, ctx.Result.(*instanceSDK.AttachVolumeResponse).Server.Volumes["1"].VolumeType)
 			},
 			AfterFunc:       deleteServer("Server"),
@@ -67,7 +71,7 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 	t.Run("Detach", func(t *testing.T) {
 		t.Run("simple block volume", core.Test(&core.TestConfig{
 			Commands:   instance.GetCommands(),
-			BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
+			BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic additional-volumes.0=block:10G")),
 			Cmd:        `scw instance server detach-volume volume-id={{ (index .Server.Volumes "1").ID }}`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
@@ -167,7 +171,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 		BeforeFunc: core.BeforeFuncCombine(
 			createPlacementGroup("PlacementGroup1"),
 			createPlacementGroup("PlacementGroup2"),
-			core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic placement-group-id={{ .PlacementGroup1.ID }}"),
+			core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic placement-group-id={{ .PlacementGroup1.ID }}")),
 		),
 		Cmd: "scw instance server update {{ .Server.ID }} placement-group-id={{ .PlacementGroup2.ID }}",
 		Check: core.TestCheckCombine(
@@ -192,7 +196,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 		BeforeFunc: core.BeforeFuncCombine(
 			createSecurityGroup("SecurityGroup1"),
 			createSecurityGroup("SecurityGroup2"),
-			core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic security-group-id={{ .SecurityGroup1.ID }}"),
+			core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic security-group-id={{ .SecurityGroup1.ID }}")),
 		),
 		Cmd: "scw instance server update {{ .Server.ID }} security-group-id={{ .SecurityGroup2.ID }}",
 		Check: core.TestCheckCombine(
@@ -223,15 +227,17 @@ func Test_ServerUpdateCustom(t *testing.T) {
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				require.NoError(t, ctx.Err)
-				assert.Equal(t, 20*scw.GB, ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes["0"].Size)
-				assert.Equal(t, 10*scw.GB, ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes["1"].Size)
+				size0 := ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes["0"].Size
+				size1 := ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes["1"].Size
+				assert.Equal(t, 20*scw.GB, instance.SizeValue(size0), "Size of volume should be 20 GB")
+				assert.Equal(t, 10*scw.GB, instance.SizeValue(size1), "Size of volume should be 10 GB")
 			},
 			AfterFunc: deleteServer("Server"),
 		}))
 
 		t.Run("detach all volumes", core.Test(&core.TestConfig{
 			Commands:   instance.GetCommands(),
-			BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
+			BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic additional-volumes.0=block:10G")),
 			Cmd:        `scw instance server update {{ .Server.ID }} volume-ids=none`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
@@ -254,7 +260,7 @@ func Test_ServerDelete(t *testing.T) {
 
 	t.Run("with all volumes", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic additional-volumes.0=block:10G")),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -265,7 +271,7 @@ func Test_ServerDelete(t *testing.T) {
 
 	t.Run("only block volumes", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic additional-volumes.0=block:10G")),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=block`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -277,7 +283,7 @@ func Test_ServerDelete(t *testing.T) {
 
 	t.Run("only local volumes", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic additional-volumes.0=block:10G")),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=local`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -289,7 +295,7 @@ func Test_ServerDelete(t *testing.T) {
 
 	t.Run("with none volumes", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic additional-volumes.0=block:10G"),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic additional-volumes.0=block:10G")),
 		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=none`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
@@ -315,7 +321,7 @@ func Test_ServerDelete(t *testing.T) {
 		),
 		BeforeFunc: core.BeforeFuncCombine(
 			core.ExecStoreBeforeCmd("BlockVolume", "scw block volume create perf-iops=5000 from-empty.size=10G name=cli-test-server-delete-with-sbs-volumes"),
-			core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-jammy"),
+			core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy")),
 			core.ExecBeforeCmd("scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .BlockVolume.ID }}"),
 		),
 		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
@@ -336,5 +342,31 @@ func Test_ServerDelete(t *testing.T) {
 		DisableParallel: true,
 	}))
 
+	t.Run("with multiple IPs", core.Test(&core.TestConfig{
+		Commands:   instance.GetCommands(),
+		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-bionic ip=both")),
+		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			core.TestCheckExitCode(0),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				t.Helper()
+
+				require.NotNil(t, ctx.Meta["Server"])
+				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				assert.Len(t, server.PublicIPs, 2)
+				api := instanceSDK.NewAPI(ctx.Client)
+				for _, ip := range server.PublicIPs {
+					_, err := api.GetIP(&instanceSDK.GetIPRequest{
+						Zone: server.Zone,
+						IP:   ip.ID,
+					})
+					assert.Error(t, err, "expected IP to be deleted")
+				}
+			},
+		),
+		DisableParallel: true,
+	}))
+
 	interactive.IsInteractive = false
 }
