@@ -7,7 +7,7 @@ import (
 	"time"
 
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
@@ -140,3 +140,10 @@ func volumeWaitCommand() *core.Command {
 		},
 	}
 }
+
+func volumeMigrationBuilder(c *core.Command) *core.Command {
+	c.ArgSpecs.DeleteByName("snapshot-id")
+	c.ArgSpecs.GetByName("volume-id").Positional = true
+
+	return c
+}
