@@ -2,7 +2,7 @@ package jobs
 
 import (
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	jobs "github.com/scaleway/scaleway-sdk-go/api/jobs/v1alpha1"
 )
