@@ -1,7 +1,7 @@
 package mnq
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	mnq "github.com/scaleway/scaleway-sdk-go/api/mnq/v1beta1"
 )
