@@ -1,7 +1,7 @@
 package tem
 
 import (
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	tem "github.com/scaleway/scaleway-sdk-go/api/tem/v1alpha1"
 )
