@@ -2,7 +2,7 @@ package tasks_test
 
 import (
 	"context"
-	"fmt"
+	"errors"
 	"os"
 	"runtime"
 	"strconv"
@@ -19,7 +19,7 @@ func TestGeneric(t *testing.T) {
 	ts.SetLoggerMode(tasks.PrinterModeQuiet)
 
 	tasks.Add(ts, "convert int to string", func(_ *tasks.Task, args int) (nextArgs string, err error) {
-		return fmt.Sprintf("%d", args), nil
+		return strconv.Itoa(args), nil
 	})
 	tasks.Add(ts, "convert string to int and divide by 4", func(_ *tasks.Task, args string) (nextArgs int, err error) {
 		i, err := strconv.ParseInt(args, 10, 32)
@@ -45,7 +45,7 @@ func TestInvalidGeneric(t *testing.T) {
 	ts.SetLoggerMode(tasks.PrinterModeQuiet)
 
 	tasks.Add(ts, "convert int to string", func(_ *tasks.Task, args int) (nextArgs string, err error) {
-		return fmt.Sprintf("%d", args), nil
+		return strconv.Itoa(args), nil
 	})
 	tasks.Add(ts, "divide by 4", func(_ *tasks.Task, args int) (nextArgs int, err error) {
 		return args / 4, nil
@@ -76,7 +76,7 @@ func TestCleanup(t *testing.T) {
 			clean++
 			return nil
 		})
-		return nil, fmt.Errorf("fail")
+		return nil, errors.New("fail")
 	})
 
 	_, err := ts.Execute(context.Background(), nil)
@@ -125,7 +125,7 @@ func TestCleanupOnContext(t *testing.T) {
 
 		select {
 		case <-task.Ctx.Done():
-			return nil, fmt.Errorf("interrupted")
+			return nil, errors.New("interrupted")
 		case <-time.After(time.Second * 3):
 			return nil, nil
 		}
